![alt text](https://travis-ci.org/xliiv/pis.svg?branch=travis)

[![Coverage Status](https://coveralls.io/repos/github/xliiv/pis/badge.svg)](https://coveralls.io/github/xliiv/pis)


# pis (Pis Installs Sources)

pis: Install python package as cloned repo from guessed VCS (git, hg, etc.)
repository.


## Example:

```
$ pis requests

TODO Rest of content

```

## Installation

`pip install pis`


## TODO:

* install package from tag, like `pis requests==2.7.0`

## Credits

* thanks to [ar4s](https://github.com/ar4s "ar4s") for great idea of getting config directly from master branch
